@@ -4,7 +4,10 @@
 # Univention Common Python Library
 """Handle UCR network configuration."""
 #
-# Copyright 2010-2021 Univention GmbH
+# Like what you see? Join us!
+# https://www.univention.com/about-us/careers/vacancies/
+#
+# Copyright 2010-2022 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -42,8 +45,8 @@ from univention.config_registry.backend import ConfigRegistry
 from ipaddress import IPv4Address, IPv6Address, IPv4Interface, IPv6Interface
 
 try:
-	from typing import Any, Callable, Dict, Iterator, Optional, Union, Tuple, Type  # noqa F401
-	from ipaddress import _IPAddressBase  # noqa F401
+	from typing import Any, Callable, Dict, Iterator, Optional, Union, Tuple, Type  # noqa: F401
+	from ipaddress import _IPAddressBase  # noqa: F401
 except ImportError:  # pragma: no cover
 	pass
 
